@@ -59,49 +59,49 @@ q2 = q+ggtitle("T3 Phenotype");
 Q = plot_grid(q1,q2,nrow=1);
 print(Q);
 
-## ---- include=T, eval=T--------------------------------------------------
-cat("Omnibus Test, Normal Phenotype, Average Correaltion Method\n");
-pn = RNOmni(y=yn,G=G,X=X,method="AvgCorr");
-round(head(pn),digits=3);
-cat("\n");
-cat("Omnibus Test, Normal Phenotype, Bootstrap Correaltion Method\n");
-pn = RNOmni(y=yn,G=G[,1:10],X=X,method="Bootstrap",B=100);
-round(head(pn),digits=3);
-cat("\n");
-cat("Omnibus Test, T3 Phenotype, Average Correaltion Method\n");
-pt = RNOmni(y=yt,G=G,X=X,method="AvgCorr");
-round(head(pt),digits=3);
-cat("\n");
-cat("Omnibus Test, T3 Phenotype, Bootstrap Correaltion Method\n");
-pt = RNOmni(y=yt,G=G[,1:10],X=X,method="Bootstrap",keep.rho=T,B=100);
-round(head(pt),digits=3);
-cat("\n");
-cat("Replicate the Omnibus Test on the T3 Phenotype, Manually Specifying Correlation\n");
-pt = RNOmni(y=yt,G=G,X=X,method="Manual",set.rho=pt[,"Corr"],keep.rho=T);
-round(head(pt),digits=3);
-cat("\n");
-
 ## ---- include=T----------------------------------------------------------
 # Basic Association Test, Normal Phenotype
-pn = BAT(y=yn,G=G,X=X);
-round(head(pn),digits=3);
+Results_BAT_Yn = BAT(y=yn,G=G,X=X);
+round(head(Results_BAT_Yn),digits=3);
 # Basic Association Test, T3 Phenotype
-pt = BAT(y=yt,G=G,X=X);
-round(head(pt),digits=3);
+Results_BAT_Yt  = BAT(y=yt,G=G,X=X);
+round(head(Results_BAT_Yt),digits=3);
 
 ## ---- include=T----------------------------------------------------------
 # Direct INT Test, Normal Phenotype
-pn = DINT(y=yn,G=G,X=X);
-round(head(pn),digits=3);
+Results_DINT_Yn = DINT(y=yn,G=G,X=X);
+round(head(Results_DINT_Yn),digits=3);
 # Direct INT Test, T3 Phenotype
-pt = DINT(y=yt,G=G,X=X);
-round(head(pt),digits=3);
+Results_DINT_Yt = DINT(y=yt,G=G,X=X);
+round(head(Results_DINT_Yt),digits=3);
 
 ## ---- include=T----------------------------------------------------------
 # Indirect INT Test, Normal Phenotype
-pn = IINT(y=yn,G=G,X=X);
-round(head(pn),digits=3);
+Results_IINT_Yn = IINT(y=yn,G=G,X=X);
+round(head(Results_IINT_Yn),digits=3);
 # Indirect INT Test, T3 Phenotype
-pt = IINT(y=yt,G=G,X=X);
-round(head(pt),digits=3);
+Results_IINT_Yt = IINT(y=yt,G=G,X=X);
+round(head(Results_IINT_Yt),digits=3);
+
+## ---- include=T, eval=T--------------------------------------------------
+cat("Omnibus Test, Normal Phenotype, Average Correlation Method\n");
+Results_OINT_Avg_Yn = OINT(y=yn,G=G,X=X,method="AvgCorr");
+round(head(Results_OINT_Avg_Yn),digits=3);
+cat("\n");
+cat("Omnibus Test, Normal Phenotype, Bootstrap Correlation Method\n");
+Results_OINT_Boot_Yn = OINT(y=yn,G=G[,1:10],X=X,method="Bootstrap",B=100);
+round(head(Results_OINT_Boot_Yn),digits=3);
+cat("\n");
+cat("Omnibus Test, T3 Phenotype, Average Correlation Method\n");
+Results_OINT_Avg_Yt = OINT(y=yt,G=G,X=X,method="AvgCorr");
+round(head(Results_OINT_Avg_Yt),digits=3);
+cat("\n");
+cat("Omnibus Test, T3 Phenotype, Bootstrap Correlation Method\n");
+Results_OINT_Boot_Yt = OINT(y=yt,G=G[,1:10],X=X,method="Bootstrap",keep.rho=T,B=100);
+round(head(Results_OINT_Boot_Yt),digits=3);
+cat("\n");
+cat("Replicate the Omnibus Test on the T3 Phenotype, Manually Specifying Correlation\n");
+Results_OINT_Boot_Yt = OINT(y=yt,G=G,X=X,method="Manual",set.rho=Results_OINT_Boot_Yt[,"Corr"],keep.rho=T);
+round(head(Results_OINT_Boot_Yt),digits=3);
+cat("\n");
 
